==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/internal/pkg/apis/duck/v1/DestinationFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface DestinationFluent<A extends DestinationFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildRef instead.
 * @return The buildable object.
 */
@Deprecated public KReference getRef();
    public KReference buildRef();
    public A withRef(KReference ref);
    public Boolean hasRef();
    public A withNewRef(String apiVersion,String kind,String name,String namespace);
    public DestinationFluent.RefNested<A> withNewRef();
    public DestinationFluent.RefNested<A> withNewRefLike(KReference item);
    public DestinationFluent.RefNested<A> editRef();
    public DestinationFluent.RefNested<A> editOrNewRef();
    public DestinationFluent.RefNested<A> editOrNewRefLike(KReference item);
    public String getUri();
    public A withUri(String uri);
    public Boolean hasUri();
    public A withNewUri(String arg1);
    public A withNewUri(StringBuilder arg1);
    public A withNewUri(StringBuffer arg1);
    public interface RefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KReferenceFluent<DestinationFluent.RefNested<N>> {

            public N and();
            public N endRef();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/internal/pkg/apis/duck/v1/DestinationFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface DestinationFluent<A extends DestinationFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildRef instead.
 * @return The buildable object.
 */
@Deprecated public KReference getRef();
    public KReference buildRef();
    public A withRef(KReference ref);
    public Boolean hasRef();
    public A withNewRef(String apiVersion,String kind,String name,String namespace);
    public DestinationFluent.RefNested<A> withNewRef();
    public DestinationFluent.RefNested<A> withNewRefLike(KReference item);
    public DestinationFluent.RefNested<A> editRef();
    public DestinationFluent.RefNested<A> editOrNewRef();
    public DestinationFluent.RefNested<A> editOrNewRefLike(KReference item);
    public String getUri();
    public A withUri(String uri);
    public Boolean hasUri();
    public A withNewUri(StringBuilder arg1);
    public A withNewUri(int[] arg1,int arg2,int arg3);
    public A withNewUri(char[] arg1);
    public A withNewUri(StringBuffer arg1);
    public A withNewUri(byte[] arg1,int arg2);
    public A withNewUri(byte[] arg1);
    public A withNewUri(char[] arg1,int arg2,int arg3);
    public A withNewUri(byte[] arg1,int arg2,int arg3);
    public A withNewUri(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUri(String arg1);
    public interface RefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KReferenceFluent<DestinationFluent.RefNested<N>> {

            public N and();
            public N endRef();    }


}
